@@ -562,11 +562,11 @@ public abstract class Page implements Serializable {
 
 	/**
 	 * 出力コンテントタイプ。
-	 * nullを返すと自動選定されます。選定方法は以下です。
+	 * nullを返すと自動選定されます。選定方法は以下です。<br>
 	 * isXML()がtrueを返し、且つ
-	 * （リクエストヘッダAcceptに application/xhtml+xml が明示されている、
-	 * または携帯からのアクセスである）場合に
-	 * application/xhtml+xml を返します。それ以外では text/html を返します。
+	 * 携帯からのアクセスである場合に
+	 * application/xhtml+xml を返します。<br>
+	 * それ以外では text/html を返します。<br>
 	 * またその時、getCharset()の戻り値を charset に指定します。
 	 * @return &quot;text/html; charset=UTF-8&quot;等
 	 */
@@ -1260,14 +1260,20 @@ public abstract class Page implements Serializable {
 				eclipse.setAttribute(
 					new Attribute( "id", AJAX_BLACK_ID )
 				);
-				Tag	iframe = new Tag( "iframe", false );
-				iframe.setAttribute(
+				Tag	temp = new Tag( "iframe", false );
+				temp.setAttribute(
+					new Attribute( "id", AJAX_TEMP_ID ),
+					new Attribute( "name", AJAX_TEMP_ID ),
+					new Attribute( "scrolling", new Text( "no" ) )
+				);
+				Tag	tail = new Tag( "iframe", false );
+				tail.setAttribute(
 					new Attribute( "onload", "paraselene.form_comp();" ),
 					new Attribute( "id", AJAX_TARGET_ID ),
 					new Attribute( "name", AJAX_TARGET_ID ),
 					new Attribute( "scrolling", new Text( "no" ) )
 				);
-				div[1].addHTMLPart( eclipse, iframe );
+				div[1].addHTMLPart( eclipse, temp, tail );
 				div[1].setAttribute(
 					new Attribute( "id", AJAX_ADD_ID )
 				);
@@ -1291,6 +1297,7 @@ public abstract class Page implements Serializable {
 
 	private static final String	AJAX_BLACK_ID = "paraseleneEclipse";
 	private static final String	AJAX_TARGET_ID = "paraseleneDragonsTail";
+	private static final String	AJAX_TEMP_ID = "paraseleneOoltCloud";
 	private static final String	AJAX_ADD_ID = "paraseleneDragonsHead";
 	private boolean ajax_f = false;
 	private RequestParameter	now_req;
@@ -1313,7 +1320,7 @@ public abstract class Page implements Serializable {
     </tr>
     <tr>
       <td>init</td>
-      <td colspan="2">null</td>
+      <td colspan="2">&lt;body&gt;</td>
     </tr>
     <tr>
       <td>firstOutput</td>
@@ -1338,6 +1345,7 @@ public abstract class Page implements Serializable {
 	 * @return body 内容を持っているタグ。
 	 */
 	public Tag getBodyTag() {
+		if ( body_tag == null )	return getFirstTagByType( "body" );
 		return body_tag;
 	}
 
