@@ -49,6 +49,15 @@ class DataHolder implements ServerInformation {
 	}
 	public HistorySet getHistorySet() { return data.hist; }
 	public PageFactory getPageFactory() { return fact; }
+
+	String encodeURL( String url, Page page ) {
+		if ( request.judgeMobile() == RequestParameter.Mobile.NO_MOBILE ) {
+			if ( page != null ) {
+				if ( !page.isEncodeURL() )	return url;
+			}
+		}
+		return response.encodeURL( url );
+	}
 }
 
 class RedirectData implements Serializable {
@@ -72,11 +81,11 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 		if ( addr == null )	return null;
 		String[]	bt = addr.split( "[\\.:]" );
 		if ( bt.length < 4 )	return addr;
-		StringBuilder	buf = new StringBuilder( bt[0] );
+		StringBuilder	buf = new StringBuilder( bt[0].trim() );
 		int	len = bt.length - 1;
 		for ( int i = 1; i < len; i++ ) {
 			buf = buf.append( "." );
-			buf = buf.append( bt[1] );
+			buf = buf.append( bt[1].trim() );
 		}
 		return buf.toString();
 	}
@@ -84,7 +93,8 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 	private int getClient( HttpServletRequest req ) {
 		String[]	data = new String[] {
 			req.getHeader( RequestParameter.UA_HEAD ),
-			getAdder( req )
+			getAdder( req ),
+			req.getHeader( RequestParameter.X_FORWARD )
 		};
 		StringBuilder	buf = new StringBuilder();
 		for ( int i = 0; i < data.length; i++ ) {
@@ -105,7 +115,7 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 	boolean isSame( HttpServletRequest req ) {
 		if ( client == getClient( req ) )	return true;
 		client = 0;
-		System.out.println( "-- nmatched client --------------------------"  );
+		System.out.println( "-- unmatched client --------------------------"  );
 		System.out.println( new Date().toString() );
 		System.out.println( "IP = " + req.getRemoteAddr() );
 		System.out.println( "User Agent = " + req.getHeader( RequestParameter.UA_HEAD ) );
