@@ -782,6 +782,7 @@ public abstract class Supervisor extends HttpServlet {
 			String	mime = out_ret[1].getContentType();
 			if ( mime == null ) {
 				StringBuilder	buf = null;
+/* 処理変更
 				if ( next_page.isXML() ) {
 					RequestParameter.HeaderQuality[]	head = param.getHeaderWithQuality( "Accept" );
 					if ( head != null ) {
@@ -804,6 +805,15 @@ public abstract class Supervisor extends HttpServlet {
 						}
 					}
 				}
+*/
+				if ( next_page.isXML() ) {
+					RequestParameter.Mobile	mob = param.judgeMobile();
+					switch( mob ) {
+					case AU: case DOCOMO: case J_PHONE:
+						buf = new StringBuilder( XHTML );
+						break;
+					}
+				}
 				if ( buf == null )	buf = new StringBuilder( "text/html" );
 				buf = buf.append( "; charset=" );
 				mime = buf.append( next_page.getCharset() ).toString();
