@@ -87,10 +87,11 @@ public class Tag extends HTMLPart {
 	private boolean modify_enable = true;
 
 	private static final String[] ERR_IE = new String[] {
-		"table", "thead", "tbody", "tfoot", "tr"
+		"table", "thead", "tbody", "tfoot", "tr",
+		"select", "option",
 	};
 
-	private boolean isTable() {
+	private boolean isModifySkip() {
 		String	name = getName();
 		for ( int i = 0; i < ERR_IE.length; i++ ) {
 			if ( ERR_IE[i].equals( name ) )	return true;
@@ -102,7 +103,7 @@ public class Tag extends HTMLPart {
 	 * フレームワークが使用します。
 	 */
 	protected void setModifyMyselef() {
-		if ( getAttribute( "id" ) == null || isTable() ) {
+		if ( getAttribute( "id" ) == null || isModifySkip() ) {
 			Tag	out = getOuterTag();
 			if ( out != null ) {
 				out.setModifyMyselef();
@@ -397,7 +398,7 @@ public class Tag extends HTMLPart {
 		if ( "name".equals( at_name ) ) {
 			Tag	out = getOuterTag();
 			while ( out != null ) {
-				if ( out.isTable() ) {
+				if ( out.isModifySkip() ) {
 					out = out.getOuterTag();
 					continue;
 				}
