@@ -64,12 +64,19 @@ public class Version {
 	}
 
 	private static boolean isHit( File f ) {
+		JarFile	file = null;
 		try{
-			JarFile	file = new JarFile( f );
+			file = new JarFile( f );
 			JarEntry	ent = file.getJarEntry( "paraselene/Version.class" );
 			return ent != null;
 		}
 		catch( Exception e ) {}
+		finally {
+			try {
+				file.close();
+			}
+			catch( Exception e ){}
+		}
 		return false;
 	}
 
@@ -168,17 +175,45 @@ public class Version {
 	 * @return 更新時間。
 	 */
 	public static HTTPDate getLastModified( String name ) {
+		JarFile	file = null;
 		name = fixName( name );
 		try {
-			JarFile	file = new JarFile( getJarPath() );
+			file = new JarFile( getJarPath() );
 			return new HTTPDate( new Date( file.getEntry( name ).getTime() ) );
 		}
 		catch( Exception e ) {
 			Option.debug( e );
 		}
+		finally {
+			try {
+				file.close();
+			}
+			catch( Exception e ) {}
+		}
 		return new HTTPDate( new Date( getJarPath().lastModified() ) );
 	}
 
+	private static InputStream jarConvert( JarFile file, String name ) {
+		InputStream	in = null;
+		try {
+			JarEntry	entry = file.getJarEntry( name );
+			byte[]	buf = new byte[(int)entry.getSize()];
+			in = file.getInputStream( entry );
+			in.read( buf );
+			return new ByteArrayInputStream( buf );
+		}
+		catch( Exception e ) {
+			Option.debug( e );
+		}
+		finally {
+			try {
+				in.close();
+			}
+			catch( Exception e ) {}
+		}
+		return null;
+	}
+
 	/**
 	 * リソースの取得。
 	 * @param name リソースの名前。
@@ -192,13 +227,20 @@ public class Version {
 			InputStream	is = ld.getResourceAsStream( name );
 			if ( is != null )	return is;
 		}
+		JarFile	file = null;
 		try {
-			JarFile	file = new JarFile( getJarPath() );
-			return file.getInputStream( file.getJarEntry( name ) );
+			file = new JarFile( getJarPath() );
+			return jarConvert( file, name );
 		}
 		catch( Exception e ){
 			Option.debug( e );
 		}
+		finally {
+			try {
+				file.close();
+			}
+			catch( Exception e ) {}
+		}
 		return null;
 	}
 }
