@@ -1,14 +1,17 @@
 /* Paraselene Copyright (c) 2009, 2010  Akira Terasaki */
 Paraselene=function(){
-this.get_id=function(id){
-	if(document.getElementById){
-		return document.getElementById(id);
-	}else if(document.all){
-		return document.all(id);
-	}else if(document.layers){
-		return document.layers[id];
+this.get_id_by_doc=function(doc,id){
+	if(doc.getElementById){
+		return doc.getElementById(id);
+	}else if(doc.all){
+		return doc.all(id);
+	}else if(doc.layers){
+		return doc.layers[id];
 	}
 };
+this.get_id=function(id){
+	return this.get_id_by_doc(document,id);
+};
 
 /*
 	0:unknown
@@ -38,6 +41,19 @@ this.init=function(){
 	}
 };
 
+this.set_inner=function(tag,c){
+	if(!tag)	return tag;
+	tag.innerHTML="";
+	var doc=this.get_iframe_document("paraseleneOoltCloud");
+	doc.open();
+	doc.write('<html><head></head><body>' + c + '</body></html>');
+	doc.close();
+	for ( i = 0; i < doc.body.childNodes.length; i++ ) {
+		tag.appendChild(doc.body.childNodes[i].cloneNode(true));
+	}
+	return tag;
+};
+
 this.max=function(a,b){
 	if(!a)	return b;
 	if(!b)	return a;
@@ -379,7 +395,7 @@ this.dialog_open=function(dialog){
 	var body=document.createElement("div");
 	body.id=dialog.id;
 	body.style.background=dialog.bg;
-	body.innerHTML=dialog.body;
+	body=this.set_inner(body,dialog.body);
 	if(dialog.move==true){
 		base.className="paraselenePopupBase paraseleneTopOrder";
 		base.style.borderColor=dialog.border;
@@ -391,7 +407,7 @@ this.dialog_open=function(dialog){
 
 		var a=document.createElement("span");
 		a.className="paraselenePopupHead";
-		a.innerHTML=dialog.title;
+		a=this.set_inner(a,dialog.title);
 		head.appendChild(a);
 
 		body.className="paraselenePopupBody";
@@ -464,6 +480,11 @@ this.location_replace=function(next){
 	return org[0]+tgt[1];
 };
 
+this.selected_index=function(form_id,name,no){
+	var f=paraselene.get_id(form_id);
+	f.elements[name].options[no].selected=true;
+};
+
 this.forwarding=false;
 this.action=function(obj){
 	var resize_f=false;
@@ -510,7 +531,7 @@ this.action=function(obj){
 		if(val.tag){
 			var update_tag=val.tag;
 			var target=paraselene.get_id(update_tag.id);
-			if(target)	target.innerHTML=update_tag.body;
+			target=this.set_inner(target,update_tag.body);
 			resize_f=true;
 			if(update_tag.cmd)	paraselene.exec(update_tag.cmd);
 			continue;
@@ -688,19 +709,29 @@ this.form_ok=function (key){
 	paraselene.get_form(key);
 };
 
+this.get_iframe_document=function( id ) {
+	var iframe=paraselene.get_id(id);
+	var doc=undefined;
+	try{
+		doc=iframe.contentDocument;
+	}catch(e){}
+	if(!doc){
+		doc=iframe.contentWindow.document;
+	}
+	return doc;
+};
+
 this.form_comp=function(){
 	if(!paraselene.called_form)	return;
-	var tail=paraselene.get_id("paraseleneDragonsTail");
-	var doc=tail.contentDocument;
-	if(!doc){
-		doc=tail.contentWindow.document;
-	}
+	var doc=this.get_iframe_document("paraseleneDragonsTail");
 	var cont="";
 	var head=doc.getElementsByTagName("head");
 	if(head){
 		if(head[0])	cont=head[0].innerHTML;
 	}
-	cont+=doc.body.innerHTML;
+	if(!doc.body && doc.body!=null){
+		cont+=doc.body.innerHTML;
+	}
 	if(cont.indexOf("form_ok")>0)	return;
 	document.open();
 	document.write(cont);
